@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2005-2021 Intel Corporation
+    Copyright (c) 2005-2023 Intel Corporation
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -1909,7 +1909,7 @@ void test_indexer_node() {
     run_indexer_node_test<std::tuple<int,int>, nonThrowing, isThrowing>();
     g_Wakeup_Msg = "indexer_node(is,is): Missed wakeup or machine is overloaded?";
     run_indexer_node_test<std::tuple<int,int>, isThrowing,  isThrowing>();
-    g_Wakeup_Msg = g_Orig_Wakeup_Msg;;
+    g_Wakeup_Msg = g_Orig_Wakeup_Msg;
 }
 
 ///////////////////////////////////////////////
@@ -1928,7 +1928,7 @@ public:
     }
 };
 
-// test from user ahelwer: http://software.intel.com/en-us/forums/showthread.php?t=103786
+// test from user ahelwer: https://community.intel.com/t5/Intel-oneAPI-Threading-Building/Exception-in-flow-graph-results-in-graph-wait-for-all-hanging/td-p/789352
 // exception thrown in graph node, not caught in wait_for_all()
 void
 test_flow_graph_exception0() {
